"""
    eHelply SDK - 1.1.89

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.89
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import ehelply_python_sdk
from ehelply_python_sdk.model.options import Options
from ehelply_python_sdk.model.validations import Validations
globals()['Options'] = Options
globals()['Validations'] = Validations
from ehelply_python_sdk.model.field import Field


class TestField(unittest.TestCase):
    """Field unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testField(self):
        """Test Field"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Field()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
