"""
    eHelply SDK - 1.1.89

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.89
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import ehelply_python_sdk
from ehelply_python_sdk.api.tag_api import TagApi  # noqa: E501


class TestTagApi(unittest.TestCase):
    """TagApi unit test stubs"""

    def setUp(self):
        self.api = TagApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_tag_places_tags_post(self):
        """Test case for create_tag_places_tags_post

        Create Tag  # noqa: E501
        """
        pass

    def test_delete_tag_places_tags_tag_uuid_delete(self):
        """Test case for delete_tag_places_tags_tag_uuid_delete

        Delete Tag  # noqa: E501
        """
        pass

    def test_get_tag_places_tags_tag_uuid_get(self):
        """Test case for get_tag_places_tags_tag_uuid_get

        Get Tag  # noqa: E501
        """
        pass

    def test_search_tags_places_tags_get(self):
        """Test case for search_tags_places_tags_get

        Search Tags  # noqa: E501
        """
        pass

    def test_update_tag_places_tags_tag_uuid_put(self):
        """Test case for update_tag_places_tags_tag_uuid_put

        Update Tag  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
